@@ -19,5 +19,5 @@ globalVariables(c(
   "p.value", ".win_size", ".row_id",
   "cds_start", "cds_end", "score",
   "n_int", "sum_overlap", "sum_x", "sum_xy", "sum_y",
-  "temp_start", "temp_end"
+  "temp_start", "temp_end", "seqnames"
 ))
